@@ -10,8 +10,8 @@ from .device import Device, Interface
 from .execution import Execution
 from .exceptions import *
 from .logger import Logger
-from .studio import Studio
+from .studio import InputError, Studio
 from .topology import Connection, Topology
 from .user import User
 
-__version__ = "1.4.1"
+__version__ = "1.4.3"
